@@ -257,8 +257,8 @@ class insightmarketservice(market_service):
 def login():
     markets = insightmarketservice()
     # 登陆前 初始化
-    user = "usename"
-    password = "password"
+    user = ""
+    password = ""
     # result格式为string格式
     result = common.login(markets, user, password)
     print(result)
@@ -298,7 +298,7 @@ def subscribe_by_type():
     marketdatatype = {"ESecurityIDSource": ESecurityIDSource.XSHG, "ESecurityType": ESecurityType.StockType,
                       "EMarketDataType": EMarketDataType.MD_SECURITY_LENDING}
     marketdatatypes.append(marketdatatype)
-    marketdatatype1 = {"ESecurityIDSource": ESecurityIDSource.XSHG, "ESecurityType": ESecurityType.StockType,
+    marketdatatype1 = {"ESecurityIDSource": ESecurityIDSource.XSHE, "ESecurityType": ESecurityType.StockType,
                        "EMarketDataType": EMarketDataType.MD_TICK}
     marketdatatypes.append(marketdatatype1)
 
@@ -338,6 +338,10 @@ def query_fin_info():
     # params2:params  dict{}
     query_type = 1102010003
     params = {"HTSC_SECURITY_ID": "510050.SH", "START_DATE": "20210101", "END_DATE": "20210107"}
+    # query_type = 1002010001
+    # params = {"HTSC_SECURITY_ID": "601688.SH", "START_DATE": "20191211", "END_DATE": "20201010"}
+    # query_type = 1002070003
+    # params = {"HTSC_SECURITY_ID": "600498.SH", "START_TIME": "20200101000000", "END_TIME": "20210107000000", "EXRIGHTS_TYPE": "NoExrights", "EMD_PERIOD_TYPE":"Period1D"}
     result = query.query_fin_info(query_type, params)
     if isinstance(result, list):
         for response in iter(result):
@@ -532,14 +536,14 @@ def main(markets=None):
     # 登陆部分调用
     get_version()
     login()
-    #config(True, True, True)
+    config(False, False, False)
     # 订阅部分接口调用
 
     subscribe_by_type()
     # subscribe_by_id()
     # 查询部分接口调用
     # query_fin_info()
-    # query_mdcontant_by_type()
+    # query_mdcontant_by_type()dd
     # query_last_mdcontant_by_type()
     # query_mdcontant_by_id()
     # query_last_mdcontant_by_id()
